@@ -20,5 +20,5 @@ UnknownPlayerName: Name = Name(UNKNOWN_PLAYER, BuiltinSource.guid)
 UnknownTeamName: Name = Name(UNKNOWN_TEAM, BuiltinSource.guid)
 """The Name for an unknown team."""
 
-NoTeam = Team(names=[Name("(Free Agent)", BuiltinSource.guid)], sources=[BuiltinSource.guid])
-UnknownTeam = Team(names=[UnknownTeamName], sources=[BuiltinSource.guid])
+NoTeam = Team(names=[Name("(Free Agent)", BuiltinSource.guid)])
+UnknownTeam = Team(names=[UnknownTeamName])
